@@ -2,6 +2,7 @@ package geoip2
 
 import (
 	"fmt"
+	"log"
 	"net"
 )
 
@@ -10,24 +11,21 @@ import (
 func Example() {
 	db, err := Open("test-data/test-data/GeoIP2-City-Test.mmdb")
 	if err != nil {
-		panic(err)
+		log.Fatal(err)
 	}
+	defer db.Close()
 	// If you are using strings that may be invalid, check that ip is not nil
 	ip := net.ParseIP("81.2.69.142")
 	record, err := db.City(ip)
 	if err != nil {
-		panic(err)
+		log.Fatal(err)
 	}
 	fmt.Printf("Portuguese (BR) city name: %v\n", record.City.Names["pt-BR"])
-	fmt.Printf("English subdivision name: %v\n",
-		record.Subdivisions[0].Names["en"])
+	fmt.Printf("English subdivision name: %v\n", record.Subdivisions[0].Names["en"])
 	fmt.Printf("Russian country name: %v\n", record.Country.Names["ru"])
 	fmt.Printf("ISO country code: %v\n", record.Country.IsoCode)
 	fmt.Printf("Time zone: %v\n", record.Location.TimeZone)
-	fmt.Printf("Coordinates: %v, %v\n", record.Location.Latitude,
-		record.Location.Longitude)
-
-	db.Close()
+	fmt.Printf("Coordinates: %v, %v\n", record.Location.Latitude, record.Location.Longitude)
 	// Output:
 	// Portuguese (BR) city name: Londres
 	// English subdivision name: England
